@@ -53,6 +53,7 @@ namespace Rmath {
     double	Rf_lgammafn(double);
     double	Rf_psigamma(double, double);
     double	Rf_fmin2(double, double);
+    double	Rf_lbeta(double, double);
     /* Selected headers from <R_ext/Applic.h> */
     typedef void integr_fn(double *x, int n, void *ex);
     void Rdqags(integr_fn f, void *ex, double *a, double *b,
@@ -332,6 +333,29 @@ TMB_ATOMIC_STATIC_FUNCTION(
 			   px[1] = Type(0);
 			   )
 
+/** \brief Atomic version of the log Beta function
+    \param x Input vector of length 2.
+    \return Vector of length 1.
+*/
+TMB_ATOMIC_STATIC_FUNCTION(
+                           // ATOMIC_NAME
+                           lbeta
+                           ,
+                           // INPUT_DIM
+                           2
+                           ,
+                           // ATOMIC_DOUBLE
+                           ty[0]=Rmath::Rf_lbeta(tx[0],tx[1]);
+                           ,
+                           // ATOMIC_REVERSE
+                           Type a[2]; a[0] = tx[0]; a[1] = 1;
+                           Type b[2]; b[0] = tx[1]; b[1] = 1;
+                           Type c[2]; c[0] = tx[0] + tx[1]; c[1] = 1;
+                           Type tmp = D_lgamma(c);
+                           px[0] = (D_lgamma(a) - tmp) * py[0];
+                           px[1] = (D_lgamma(b) - tmp) * py[0];
+                           )
+
 /** \brief Atomic version of poisson cdf \f$ppois(n,\lambda)\f$.
     Valid parameter range: \f$x =(n,\lambda) \in \mathbb{N}_0\times\mathbb{R}_+\f$.
     \warning No check is performed on parameters
@@ -496,7 +520,7 @@ TMB_ATOMIC_VECTOR_FUNCTION(
 			   res = -matmul(Yt, tmp);             // -f(X)^T*W*f(X)^T
 			   )
 
-/** \brief Atomic version of log determinant of positive definite n-by-n matrix.
+/** \brief Atomic version of log absolute determinant of general invertible n-by-n matrix.
     \param x Input vector of length n*n.
     \return Vector of length 1.
 */
@@ -512,12 +536,14 @@ TMB_ATOMIC_VECTOR_FUNCTION(
 			   matrix<double> X=vec2mat(tx,n,n);
 			   matrix<double> LU=X.lu().matrixLU();    // Use Eigen LU decomposition
 			   vector<double> LUdiag = LU.diagonal();
-			   double res=LUdiag.abs().log().sum();    // TODO: currently PD only - take care of sign.
+			   double res=LUdiag.abs().log().sum();
 			   ty[0] = res;
 			   ,
-			   // ATOMIC_REVERSE  (X^-1*W[0])
-			   CppAD::vector<Type> invX = matinv(tx);
-			   for(size_t i=0; i<tx.size(); i++) px[i] = invX[i] * py[0];
+			   // ATOMIC_REVERSE  (X^-1^T*W[0])
+			   int n=sqrt((double)tx.size());
+			   matrix<Type> M = vec2mat(matinv(tx), n, n).transpose();
+			   CppAD::vector<Type> invXT = mat2vec(M);
+			   for(size_t i=0; i<tx.size(); i++) px[i] = invXT[i] * py[0];
 			   )
 
 /** \brief Atomic version of log determinant *and* inverse of positive definite n-by-n matrix.
